#ifndef __WIZPROPTREEPANE_H
#define __WIZPROPTREEPANE_H

#include "wizproptree.h"


/*********************************************************************

  wizproptreepane.cpp

  Author:  Russell Morris
  Release: February 26, 1997

  Class definition of TWizPropTreePane
  
*********************************************************************/

class TWizPropTreePane : public TPropTreePane {

  public:
    TWizPropTreePane( TWizPropTreeDialog* parent,
                      uint32          uniqueId,
                      const char far *helpText,
                      TResId          resId,
                      bool            isLast = false,
                      TModule*        module = 0);

    virtual ~TWizPropTreePane();

    // Called by TWizPropTreeDialog to determine what type of bitmap to
    // display.
    //
    virtual TWizardUpdate
    GetWizPaneStatus();

    // Returns info about where this step leads to...
    //
    virtual uint32 WhereToNext();

    // Notifies the TWizPropTreeDialog that this pane has changed status.
    // You don't normally need to use this, as the proptree will check
    // your status after you return false from KillActive.  Use this if
    // you need some nonlinear functionality...
    //
    void WizPaneStatusChange();

    // Redefine these methods do implement some default behaviour all
    // panes should have: at the very least, a pane should require that
    // it be visited before considering itself "wuDone".  If you need a
    // pane that doesn't need to be visited, return wuNonDeterminate in
    // GetWizPaneStatus()
    //
    virtual bool KillActive();
    virtual bool SetActive();

    // In our SetupWindow, set "to" and "from" to GetId() +1 and -1,
    // respectively.  This default behaviour means that when you add the
    // root pane, you will need to manually call SetFrom(-1) so that the
    // proptree knows you're back button should be disabled.
    //
    virtual void SetupWindow();

  protected:

    // Tell a pane where they're from and where they lead to
    //
    void SetFrom( uint32 pane );
    void SetTo( uint32 pane );

    // Get/Set our wuXxxx status.
    //
    TWizardUpdate GetWuStatus();
    void SetWuStatus( TWizardUpdate wu );

    // Wrap the cast in a function so you don't have to deal with it
    // in your code (unless you want functionality built into your specific
    // TWizPropTreeDialog class).
    //
    TWizPropTreeDialog*
     GetWizPropTree();

    // Wrap the call to GetWizData for ease of coding
    //
    TWizData* GetWizData();

  private:

    // Where we're from, where we lead to...
    //
    uint32 from;
    uint32 to;

    // are we the last pane in the chain?
    //
    bool last;

    // How we're doing...
    //
    TWizardUpdate status;
};


//inlines
//

inline void
TWizPropTreePane::SetFrom( uint32 pane )
{
  from = pane;
}


inline void
TWizPropTreePane::SetTo( uint32 pane )
{
  to = pane;
}


inline TWizPropTreeDialog*
TWizPropTreePane::GetWizPropTree()
{
  return dynamic_cast<TWizPropTreeDialog*>(Parent);
}

inline TWizardUpdate
TWizPropTreePane::GetWuStatus()
{
  return status;
}
#endif